@@ -1,5 +1,7 @@
 import mcpi
 
+from mcpi.vec3 import Vec3
+
 from .thing import Thing
 
 
@@ -16,17 +18,21 @@ class House(Thing):
         init_y = self.position.y
         init_z = self.position.z
 
+        end_x = init_x + self.length-1
+        end_y = init_y + self.height-1
+        end_z = init_z + self.width-1
+
         self.server.setBlocks(
             init_x, init_y, init_z,
-            init_x + self.length-1, init_y + self.height-1, init_z + self.width-1,
+            end_x, end_y, end_z,
             self.block)
 
         # Fill the cube with air so it becomes a kind of house
         self.server.setBlocks(
             init_x + self.wall_width, init_y, init_z + self.wall_width,
-            init_x + self.length-1 - self.wall_width,
-            init_y + self.height-1 - self.wall_width,
-            init_z + self.width-1 - self.wall_width,
+            end_x - self.wall_width,
+            end_y - self.wall_width,
+            end_z - self.wall_width,
             mcpi.block.AIR)
 
         # Add a door
@@ -35,4 +41,6 @@ class House(Thing):
             init_x + 1, init_y + self.door_size, init_z + self.door_size,
             mcpi.block.AIR)
 
+        self._end_position = Vec3(end_x, end_y, end_z)
+
 
